#!/usr/bin/env python

# Copyright (C) 2002 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyX; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import curses

##############################################################################
# descriptions for functions and keys
#
# descriptions: dictionary with entries
#  "global":   global function descriptions
#  "filelist": filelist function descriptions
#  "playlist": playlistlist function descriptions
# which map from
#   name of function to 
#   2-tuple of very short (for statusbar) and short description of
#   corresponding function
#
# keyname:  dictionary which maps from  keycodes to the names of the keys
##############################################################################

descriptions = {
    "global": {
          "refresh":           ("refresh", "refresh display"),
          "exit":              ("exit", "exit PyTone (press twice)"), 
          "playerstart":       ("play", "start main player"),
          "playernextsong":    ("next song", "advance to next song"),
          "playerstop":        ("stop", "stop main player"),
          "playlistdeleteplayedsongs":
                               ("delete played", "delete played songs from playlist"),
          "playlistclear":     ("clear", "clear playlist"),
          "playlistsave":      ("save", "save playlist"),
          "playlistload":      ("load", "load playlist"),
          "showhelp":          ("help", "show help"),
          "volumeup":          ("volume up", "increase output volume"),
          "volumedown":        ("volume down", "decrease output volume"),
    },
    "filelist": {
          "selectnext":        ("down", "move to the next entry"),
          "selectprev":        ("up", "move to the previous entry"),
          "selectnextpage":    ("page down", "move to the next page"),
          "selectprevpage":    ("page up", "move to previous page"),
          "selectfirst":       ("first", "move to the first entry"),
          "selectlast":        ("last", "move to the last entry"),
          "dirdown":           ("enter dir", "enter selected directory"),
          "dirup":             ("exit dir", "go directory up"),
          "addsongtoplaylist": ("add song", "add song to playlist"),
          "adddirtoplaylist":  ("add dir", "add directory recursively to playlist"),
          "activateplaylist":  ("switch to playlist", "switch to playlist window"),
          "toggleview":        ("toggle view", "toggle between database and filesystem view"),
          "generaterandomlist":("random suggestion", "generate random song list"),
          "search":            ("search", "search entry")
          },
    "playlist": {
          "selectnext":        ("down", "move to the next entry"),
          "selectprev":        ("up", "move to the previous entry"),
          "selectnextpage":    ("page down", "move to the next page"),
          "selectprevpage":    ("page up", "move to previous page"),
          "selectfirst":       ("first", "move to the first entry"),
          "selectlast":        ("last", "move to the last entry"),
          "moveitemup":        ("move song up", "move song up"),  
          "moveitemdown":      ("move song down", "move song down"),
          "deleteitem":        ("delete", "delete entry"),
          "activatefilelist":  ("switch to database", "switch to database window"),
          }
    }

# prefill keynames 
keynames = {}
for c in range(32):
    keynames[c] = "CTRL-"+chr(c+64)
for c in range(33, 128):
    keynames[c] = chr(c)


# special keys (incomplete, but sufficient list)
keynames[ord("\t")]            = "<TAB>"
keynames[ord("\n")]            = "<Return>"
keynames[27]                   = "<ESC>"
keynames[32]                   = "<Space>"
keynames[curses.KEY_BACKSPACE] = "<Backspace>"
keynames[curses.KEY_DC]        = "<Del>"
keynames[curses.KEY_DOWN]      = "<Down>"
keynames[curses.KEY_END]       = "<End>"
keynames[curses.KEY_ENTER]     = "<Enter>"
keynames[curses.KEY_HOME]      = "<Home>"
keynames[curses.KEY_IC]        = "<Insert>"
keynames[curses.KEY_LEFT]      = "<Left>"
keynames[curses.KEY_NPAGE]     = "<PageDown>"
keynames[curses.KEY_PPAGE]     = "<PageUp>"
keynames[curses.KEY_RIGHT]     = "<Right>"
keynames[curses.KEY_UP]        = "<Up>"

for key in keynames.keys():
    keynames[key+1024] = "ALT-"+keynames[key]


