#!/usr/bin/env python

# Copyright (C) 2002 Jrg Lehmann <joerg@luga.de>
#
# This file is part of PyTone (http://www.luga.de/pytone/)
#
# PyTone is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 2
# as published by the Free Software Foundation.
#
# PyTone is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with PyX; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import curses
import events
import help
import config
import window

def getitems(section):
    items = []
    if section:
        for function in config.keybindings[section].keys():
            keys = list(config.keybindings[section][function])
            keys.sort()
            keynames = []
            for key in keys:
                keynames += [help.keynames[key]]
            descr = help.descriptions[section][function][1]
            items += [(keynames, descr)]

    return items


class helpwin(window.window):

    def showitems(self, items):
        y = 1
        for item in items:
            self.win.move(y, 1)
            self.win.clrtoeol()
            for keyname in item[0][:-1]:
                self.win.addstr(keyname, curses.A_BOLD)
                self.win.addstr("/")
            self.win.addstr(item[0][-1], curses.A_BOLD)
            assert type(item[1])==type(""), item[1]
            self.win.addstr(y, 35, item[1])
            y += 1

    def __init__(self, screen, h, w, y, x, channel, timer):
        self.maxh = h
        self.maxw = w
        self.channel = channel
        self.timer = timer
        
        # for identification purposes, we only generate this once
        self.hidewindowevent = events.hidewindow(self)

        window.window.__init__(self,
                               screen, 1, 1, 0, 0, "PyTone Help", 0)

        self.channel.subscribe(events.hidewindow, self.hidewindow)
        self.channel.subscribe(events.keypressed, self.keypressed)

    def showhelp(self, context):
        items = getitems("global")+getitems(context)
        items.sort()

        height = len(items)+2
        width = int(self.maxw*0.8)
        y = (self.maxh-height)/2
        x = (self.maxw-width)/2

        self.reset(height, width, y, x, "PyTone Help", 0)
        self.showitems(items)
        
        window.window.update(self)

        # now we put the help window on top and activate it
        self.top()

        self.timer.sendeventin(self.hidewindowevent, 5, replace=1)

    # event handler

    def keypressed(self, event):
        if self.hasfocus():
            self.hide()
            raise events.TerminateEventProcessing
